//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Screen saver configuration view.

#include "SamhainConfigView.h"

#include <cstring>

#include <Button.h>
#include <Message.h>
#include <Point.h>
#include <Rect.h>
#include <TabView.h>
#include <TextView.h>
#include <View.h>

#include "Samhain.h"
#include "SamhainKnotConfigView.h"
#include "SamhainPreferences.h"
#include "SamhainSaverConfigView.h"

SamhainConfigView::SamhainConfigView(
	BRect frame, SamhainPreferences &preferences)
:	inherited(frame, "Samhain", B_WIDTH_FROM_LABEL),
	mPreferences(preferences)
{
	// empty
}

SamhainConfigView::~SamhainConfigView(void)
{
	// empty
}

void
SamhainConfigView::AttachedToWindow(void)
{
	inherited::AttachedToWindow();
	const rgb_color viewColor = ViewColor();
	
	BRect frame = Bounds();
	frame.InsetBy(5.0, 5.0);
	frame.bottom -= TabHeight();
	const BRect subFrame = frame.OffsetToCopy(B_ORIGIN);
	
	// Add copyright & disclaimer tab.	
	BTextView *pAboutView =
		new BTextView(frame, "About", subFrame,
						  B_FOLLOW_ALL, B_WILL_DRAW);
	pAboutView->SetText("Samhain " SAMHAIN_VERSION "\n"
							  "\n"
							  "\tCeltic knotwork à la Andy Sloss.\n"
							  "\tCopyright © 1997–2000  Jens Kilian\n"
							  "\t<jjk@acm.org>\n"
							  "\n"
							  "Samhain comes with ABSOLUTELY NO WARRANTY; "
							  "it is free software, and you are welcome "
							  "to redistribute it under certain conditions.  "
							  "See the GNU General Public License for details.");
	pAboutView->SetViewColor(viewColor);
	pAboutView->SetStylable(true);
	pAboutView->SetFontAndColor(be_plain_font);
	const char *pText = pAboutView->Text();
	pAboutView->SetFontAndColor(0, strchr(pText, '\n') - pText, be_bold_font);
	pAboutView->MakeEditable(FALSE);
	pAboutView->MakeSelectable(FALSE);

	BButton *pReset =
		new BButton(subFrame, "reset", "Defaults", new BMessage(kReset));
	pReset->ResizeToPreferred();
	pReset->MoveTo(subFrame.left + 5.0,
						subFrame.bottom - pReset->Bounds().Height() - 10.0);
	pAboutView->AddChild(pReset);
	pReset->SetTarget(this);
	
	AddTab(pAboutView, new BTab);

	// Add main saver preferences tab.
	AddTab(new SamhainSaverConfigView(frame, "Saver",
												 0, 25, 6,
												 0, 30000000, 7,
												 mPreferences.SaverPreferences()),
			 new BTab);
	
	// Add preview preferences tab.
	AddTab(new SamhainSaverConfigView(frame, "Preview",
												 0, 10, 11,
												 0, 10000000, 11,
												 mPreferences.PreviewPreferences()),
			 new BTab);
	
	// Add knot preferences tab.
	AddTab(new SamhainKnotConfigView(frame, "Knots",
												mPreferences.KnotPreferences()),
			 new BTab);
	
	// Select the first tab to be shown.
	Select(0);
}

void
SamhainConfigView::MessageReceived(BMessage *pMsg)
{
	switch (pMsg->what) {
	
	// Reset preferences.
	case kReset:
		mPreferences.SetDefaults();
		break;
	
	default:
		inherited::MessageReceived(pMsg);
		break;
	}
}
