//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Base class for saver/preview configuration views.

#include "SamhainConfigViewBase.h"

class BHandler;
#include <Message.h>
#include <Rect.h>
#include <View.h>
	
// Message field names.
static const char kFieldCommand[] = "Samhain:command";
static const char kFieldSource[] = "source";

SamhainConfigViewBase::SamhainConfigViewBase(BRect frame, const char *pName)
:	inherited(frame, pName, B_FOLLOW_ALL, 0)
{
	// empty
}

SamhainConfigViewBase::~SamhainConfigViewBase(void)
{
	// empty
}

void
SamhainConfigViewBase::AttachedToWindow(void)
{
	inherited::AttachedToWindow();
	SetViewColor(Parent()->ViewColor());
}

void
SamhainConfigViewBase::MessageReceived(BMessage *pMsg)
{
	switch (pMsg->what) {
	
	// Evaluate a function object.
	case kCommand:
		ProcessCommand(*pMsg);
		break;
	
	default:
		inherited::MessageReceived(pMsg);
		break;
	}
}

// Create a message for a given function object.
BMessage *
SamhainConfigViewBase::CreateCommandMessage(Command &cmd) const
{
	BMessage message(kCommand);
	if (message.AddPointer(kFieldCommand, &cmd) != B_OK) {
		return 0;
	}
	return new BMessage(message);
}
	
// Process a message containing a function object.
void
SamhainConfigViewBase::ProcessCommand(BMessage &msg) const
{
	void *pPointer;
	if (msg.FindPointer(kFieldSource, &pPointer) == B_OK) {
		BHandler *pSource = static_cast<BHandler *>(pPointer);
		if (msg.FindPointer(kFieldCommand, &pPointer) == B_OK) {
			Command *pCommand = static_cast<Command *>(pPointer);
			
			if (pSource && pCommand) {
				(*pCommand)(*pSource, msg);
			}
		}
	}
}
