//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Base class for saver/preview configuration views.

#ifndef SAMHAINCONFIGVIEWBASE_H
#define SAMHAINCONFIGVIEWBASE_H

class BHandler;
class BMessage;
#include <Rect.h>
#include <View.h>

class SamhainConfigViewBase : public BView
{
	typedef BView inherited;
public:
	SamhainConfigViewBase(BRect frame, const char *pName);
	virtual ~SamhainConfigViewBase(void);

	// Hook functions.
	virtual void AttachedToWindow(void);
	virtual void MessageReceived(BMessage *pMsg);

	// Function object base class.
	class Command
	{
	public:
		Command(void)
		{
			// empty
		}
		virtual ~Command(void)
		{
			// empty
		}
		
		virtual void operator ()(BHandler &src, BMessage &msg) = 0;
	
	private:
		Command(const Command &);
		Command &operator =(const Command &);
	};

protected:
	// Create a message for a given function object.
	BMessage *CreateCommandMessage(Command &cmd) const;
	
private:
	SamhainConfigViewBase(const SamhainConfigViewBase &);
	SamhainConfigViewBase &operator =(const SamhainConfigViewBase &);
	
	// Message type codes.
	enum {
		kCommand = ' cmd'						// evaluate function object
	};

	// Process a message containing a function object.
	void ProcessCommand(BMessage &msg) const;
};

#endif // SAMHAINCONFIGVIEWBASE_H
