//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Objects storing the screen saver preferences.

#ifndef SAMHAINPREFERENCES_H
#define SAMHAINPREFERENCES_H

#include <Locker.h>
class BMessage;
#include <SupportDefs.h>

// Preferences for the screen saver.
class SamhainSaverPreferences
{
public:
	SamhainSaverPreferences(BLocker &locker);

	// Loading and saving the current state.
	status_t LoadState(BMessage &msg);
	status_t SaveState(BMessage &msg) const;

	// Inquiry methods.
	int16 MinNumKnots(void) const;
	int16 MaxNumKnots(void) const;
	bigtime_t MinDelay(void) const;
	bigtime_t MaxDelay(void) const;
	float MinSize(void) const;
	float MaxSize(void) const;
	
	// Modification methods.
	void SetMinNumKnots(int16 minNumKnots);
	void SetMaxNumKnots(int16 maxNumKnots);
	void SetMinDelay(bigtime_t minDelay);
	void SetMaxDelay(bigtime_t maxDelay);
	void SetMinSize(float minSize);
	void SetMaxSize(float maxSize);
	
private:
	SamhainSaverPreferences(const SamhainSaverPreferences &);
	SamhainSaverPreferences &operator =(const SamhainSaverPreferences &);
	
	// Data members.
	mutable BLocker &mLocker;
	
	int16 mMinNumKnots;		// minimal/maximal number of knots
	int16 mMaxNumKnots;
	bigtime_t mMinDelay;		// minimal/maximal delay
	bigtime_t mMaxDelay;
	float mMinSize;			// minimal/maximal size (% screen size)
	float mMaxSize;
};

// Preferences for the knot engine.
class SamhainKnotPreferences
{
public:
	SamhainKnotPreferences(BLocker &locker);

	// Loading and saving the current state.
	status_t LoadState(BMessage &msg);
	status_t SaveState(BMessage &msg) const;
	
	// Inquiry methods.
	float KnotProbability1(void) const;
	float KnotProbability2(void) const;
	float SectionProbability1(void) const;
	float SectionProbability2(void) const;
	float CornerProbability1(void) const;
	float CornerProbability2(void) const;
	float FatKnotProbability(void) const;
	float HollowKnotProbability(void) const;

	// Modification methods.
	void SetKnotProbability1(float knotProbability1);
	void SetKnotProbability2(float knotProbability2);
	void SetSectionProbability1(float sectionProbability1);
	void SetSectionProbability2(float sectionProbability2);
	void SetCornerProbability1(float cornerProbability1);
	void SetCornerProbability2(float cornerProbability2);
	void SetFatKnotProbability(float fatKnotProbability);
	void SetHollowKnotProbability(float hollowKnotProbability);

private:
	SamhainKnotPreferences(const SamhainKnotPreferences &);
	SamhainKnotPreferences &operator =(const SamhainKnotPreferences &);
	
	// Data members.
	mutable BLocker &mLocker;
	
	float mKnotProbability1;			// distribution of knot types
	float mKnotProbability2;
	float mSectionProbability1;		// distribution of section types
	float mSectionProbability2;
	float mCornerProbability1;			// distribution of corner types
	float mCornerProbability2;
	float mFatKnotProbability;			// probability of subtypes
	float mHollowKnotProbability;
	// ### TO DO: colors
};

// All preferences.
class SamhainPreferences
{
public:
	SamhainPreferences(void);

	// Loading and saving the current state.
	status_t LoadState(BMessage &msg);
	status_t SaveState(BMessage &msg) const;
	
	// Access to components.
	const SamhainSaverPreferences &SaverPreferences(void) const;
	SamhainSaverPreferences &SaverPreferences(void);
	const SamhainSaverPreferences &PreviewPreferences(void) const;
	SamhainSaverPreferences &PreviewPreferences(void);
	const SamhainKnotPreferences &KnotPreferences(void) const;
	SamhainKnotPreferences &KnotPreferences(void);
	
	// Establish default values.
	void SetDefaults(void);
	
private:
	SamhainPreferences(const SamhainPreferences &);
	SamhainPreferences &operator =(const SamhainPreferences &);
	
	// Data members.
	mutable BLocker mLocker;
	
	SamhainSaverPreferences mSaverPreferences;
	SamhainSaverPreferences mPreviewPreferences;
	SamhainKnotPreferences mKnotPreferences;
};
	
#endif // SAMHAINPREFERENCES_H
