//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		A class representing a random closed knot.

#include "ClosedKnot.h"

#include <Point.h>
#include <Rect.h>
#include <View.h>

#include "KnotSection.h"
#include "RandomKnot.h"
class SamhainKnotPreferences;

ClosedKnot::ClosedKnot(BView *pView, const SamhainKnotPreferences &preferences)
:	inherited(pView, preferences, 12)
{
	if (IsValid()) {
		// Set boundary conditions for a closed knot.
		int i;
	
		// The left and right border must consist of vertical...
		for (i = 0; i < mHeight; ++i) {
			mpSectionTypes[i * mWidth] = V;
			mpSectionTypes[(i+1) * mWidth - 1] = V;
		}
		
		// ... half sections.
		for (i = 0; i <= mHeight; ++i) {
			mpSectionCorners[i * (mWidth+1)] = N;
			mpSectionCorners[(i+1) * (mWidth+1) - 1] = N;
		}

		// The top and bottom border must have horizontal corners.		
		for (i = 1; i < mWidth; ++i) {
			mpSectionCorners[i] = H;
			mpSectionCorners[mHeight*(mWidth+1) + i] = H;
		}
	}
}

ClosedKnot::~ClosedKnot(void)
{
	// empty
}

bool
ClosedKnot::Draw(void)
{
	if (IsValid()) {
		// Place the knot randomly.
		DrawAt(LocateKnot());
		mpView->Sync();
		return true;
	}
	return false;
}
