//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		A class representing a random vertically tileable knot.

#include "VerticalKnot.h"

#include <Point.h>
#include <Rect.h>
#include <View.h>

#include "KnotSection.h"
#include "RandomKnot.h"
#include "RandomNumbers.h"
class SamhainKnotPreferences;

VerticalKnot::VerticalKnot(
	BView *pView, const SamhainKnotPreferences &preferences)
:	inherited(pView, preferences, 6, 1, 4 + randomInteger(4))
{
	if (IsValid()) {
		// Set boundary conditions for a vertical knot.
		int i;
	
		// The left and right borders must have vertical corners.
		for (i = 0; i <= mHeight; ++i) {
			mpSectionCorners[i * (mWidth+1)] = V;
			mpSectionCorners[(i+1) * (mWidth+1) - 1] = V;
		}
		
		// The top and bottom borders must match.		
		for (i = 1; i < mWidth; ++i) {
			mpSectionCorners[mHeight*(mWidth+1) + i] = mpSectionCorners[i];
		}
	}
}

VerticalKnot::~VerticalKnot(void)
{
	// empty
}

bool
VerticalKnot::Draw(void)
{
	if (IsValid()) {
		// Place the knot randomly, then tile it across the screen.
		const BRect bounds = mpView->Bounds();
		const BPoint size = Size();
		BPoint where = LocateKnot();
		for (where.y = 0; where.y < bounds.Height(); where.y += size.y) {
			DrawAt(where);
		}
		mpView->Sync();
		return true;
	}
	return false;
}
